# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Params-Coerce
Version:	0.14
Release:	30.%{__distinit}%{__distvers}
Summary:	Allows your classes to do coercion of parameters
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Params-Coerce
Source0:	https://cpan.metacpan.org/modules/by-module/Params/Params-Coerce-%{version}.tar.gz
Patch0:		https://rt.cpan.org/Ticket/Attachment/1727800/928987/Params-Coerce-0.14-Fix-building-on-Perl-without-.-in-INC.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
# Dependencies of bundled Module::Install
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(YAML)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Params::Util) >= 0.05
BuildRequires:	perl(Scalar::Util) >= 1.09
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
A big part of good API design is that we should be able to be flexible in
the ways that we take parameters. Params::Coerce attempts to encourage this,
by making it easier to take a variety of different arguments, while adding
negligible additional complexity to your code.

%prep
%setup -q -n Params-Coerce-%{version}

# Fix building on Perl without "." in @INC (CPAN RT#121730)
%patch0 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTOMATED_TESTING=1

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Params/
%{_mandir}/man3/Params::Coerce.3*

%changelog
* Fri Jul  6 2018 Paul Howarth <paul@city-fan.org> - 0.14-30
- Switch upstream from search.cpan.org to metacpan.org

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 0.14-28
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun  4 2017 Paul Howarth <paul@city-fan.org> - 0.14-26
- Fix building on Perl without "." in @INC (CPAN RT#121730)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Thu Sep 15 2016 Paul Howarth <paul@city-fan.org> - 0.14-23
- Classify buildreqs by usage
- Simplify find command using -delete

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.14-19
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.14-12
- BR: perl(Cwd), perl(ExtUtils::MakeMaker), perl(File::Path) and
  perl(File::Spec)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Feb 15 2012 Paul Howarth <paul@city-fan.org> - 0.14-11
- Resync with Fedora

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.14-9
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.14-8
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 19 2010 Paul Howarth <paul@city-fan.org> - 0.14-7
- Fix dist tag for RHEL-6 Beta

* Fri Jan 29 2010 Paul Howarth <paul@city-fan.org> - 0.14-6
- Import from Fedora

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.14-5
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Mar  4 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.14-2
- Rebuild for new perl

* Sun Oct 15 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.14-1
- Update to 0.14

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-2
- Add additional verbosity to %%description 

* Tue Sep 05 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.13-1
- Specfile autogenerated by cpanspec 1.69.1
